@@ -8,12 +8,14 @@ use warnings;
     BEGIN {
         use version qw[qv];
         our $SVN
-            = q[$Id: Tracker.pm 23 2008-06-18 02:35:47Z sanko@cpan.org $];
-        our $VERSION = sprintf q[%.3f], version->new(qw$Rev: 23 $)->numify / 1000;
+            = q[$Id: Tracker.pm 24 2008-07-01 23:52:15Z sanko@cpan.org $];
+        our $VERSION = sprintf q[%.3f], version->new(qw$Rev: 24 $)->numify / 1000;
     }
+    use lib q[../../../../lib];
     use Net::BitTorrent::Util qw[min bdecode max compact shuffle :log];
     use Socket qw[SOL_SOCKET /TIMEO/ /F_INET/ SOCK_STREAM];
     use Fcntl qw[F_SETFL O_NONBLOCK];
+    use Errno qw[EINPROGRESS EWOULDBLOCK];
     {
         my (%urls,                 %fileno,
             %socket,               %session,
@@ -46,7 +48,6 @@ use warnings;
         }
 
         sub get_urls {
-            die if $_[1];
             return $urls{$_[0]};
         }
 
@@ -61,67 +62,54 @@ use warnings;
         }
 
         sub _get_fileno {
-            die if $_[1];
             return $fileno{$_[0]};
         }
 
         sub _get_socket {
-            die if $_[1];
             return $socket{$_[0]};
         }
 
         sub get_session {
-            die if $_[1];
             return $session{$_[0]};
         }
 
         sub get_client {
-            die if $_[1];
             return $session{$_[0]}->get_client;
         }
 
         sub _get_connection_timestamp {
-            die if $_[1];
             return $connection_timestamp{$_[0]};
         }
 
         sub _get_scrape_complete {
-            die if $_[1];
             return $scrape_complete{$_[0]};
         }
 
         sub _get_scrape_incomplete {
-            die if $_[1];
             return $scrape_incomplete{$_[0]};
         }
 
         sub _get_scrape_downloaded {
-            die if $_[1];
             return $scrape_downloaded{$_[0]};
         }
 
         sub _get_connected {
-            die if $_[1];
             return $connected{$_[0]};
         }
 
         sub _get_queue_outgoing {
-            die if $_[1];
             return $queue_outgoing{$_[0]};
         }
 
         sub _get_queue_incoming {
-            die if $_[1];
             return $queue_incoming{$_[0]};
         }
 
         sub _get_next_announce {
-            die if $_[1];
             return $next_announce{$_[0]};
         }
 
         sub _get_next_scrape {
-            die if $_[1];
             return $next_scrape{$_[0]};
         }
 
@@ -281,8 +269,8 @@ use warnings;
                   not
                   connect($socket, pack(q[Sna4x8], &AF_INET, $port, $resolve))
                   and $^E
-                  and ($^E != 10036)
-                  and ($^E != 10035))
+                  and ($^E != EINPROGRESS)
+                  and ($^E != EWOULDBLOCK))
             {   $self->get_client->_do_callback(q[tracker_error],
                                         sprintf q[Failed to connect: %s (%d)],
                                         $^E, $^E + 0);
@@ -497,16 +485,18 @@ use warnings;
             my ($self, $advanced) = @_;
             $session{$self}->get_client->_do_callback(q[log], TRACE,
                      sprintf(q[Entering %s for %s], [caller 0]->[3], $$self));
-            my @values = (
-                        $urls{$self}->[0],
-                        (q[=] x (27 + length($urls{$self}->[0]))),
-                        ($scrape_complete{$self} + $scrape_incomplete{$self}),
-                        $scrape_complete{$self},
-                        $scrape_incomplete{$self},
-                        $scrape_downloaded{$self},
-                        $next_scrape{$self} - time,
-                        $next_announce{$self} - time,
-                        $session{$self}->get_client->_get_pulse($self) - time,
+            my @values = ($urls{$self}->[0],
+                          (q[=] x (27 + length($urls{$self}->[0]))),
+                          (  ($scrape_complete{$self} || 0)
+                           + ($scrape_incomplete{$self} || 0)
+                          ),
+                          ($scrape_complete{$self}   || 0),
+                          ($scrape_incomplete{$self} || 0),
+                          ($scrape_downloaded{$self} || 0),
+                          ($next_scrape{$self} - time),
+                          ($next_announce{$self} - time),
+                          $session{$self}->get_client->_get_pulse($self)
+                              - time,
             );
             $_ = (sprintf q[%dm %ss%s],
                   int(abs($_) / 60),
@@ -678,6 +668,6 @@ Noncommercial-Share Alike 3.0 License
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: Tracker.pm 23 2008-06-18 02:35:47Z sanko@cpan.org $
+=for svn $Id: Tracker.pm 24 2008-07-01 23:52:15Z sanko@cpan.org $
 
 =cut
